@@ -1,5 +1,6 @@
 # -*- coding: utf-8; -*-
 
+import sys
 import os.path
 import itertools
 import argparse
@@ -65,6 +66,7 @@ class Environment(dict):
         arduino_dist_dir_guesses.insert(0, '/Applications/Arduino.app/Contents/Resources/Java')
 
     default_board_model = 'uno'
+    ino = sys.argv[0]
 
     def dump(self):
         if not os.path.isdir(self.build_dir):
@@ -240,6 +242,21 @@ class Environment(dict):
                 print all_models.format()
                 raise Abort('%s is not a valid board model' % board_model)
 
+    @property
+    def arduino_lib_version(self):
+        self.find_arduino_file('version.txt', ['lib'],
+                               human_name='Arduino lib version file (version.txt)')
+
+        if 'arduino_lib_version' not in self:
+            with open(self['version.txt']) as f:
+                print 'Detecting Arduino software version ... ',
+                v_string = f.read().strip()
+                v = Version.parse(v_string)
+                self['arduino_lib_version'] = v
+                print colorize("%s (%s)" % (v, v_string), 'green')
+
+        return self['arduino_lib_version']
+
 
 class BoardModels(OrderedDict):
     def format(self):
